import Image from "next/image";
import Link from "next/link";

export interface ExpressionSetInfo {
  id: number;
  name: string;
  description: string;
  word_count: number;
}

export function ExpressionSetInfo({
  id,
  name,
  description,
  word_count,
}: ExpressionSetInfo) {
  return (
    <section className="expression-set-info">
      <h2 className="expression-set-info-header">
        <span className="expression-set-info-name">{name}</span>
        <Link
          href={{
            pathname: "expression-set/settings",
            query: {
              "set-id": id,
            },
          }}
          passHref
        >
          <a className="icon-button justify-end">
            <Image
              src="/icons/settings.svg"
              width="24"
              height="24"
              alt="settings"
            />
          </a>
        </Link>
      </h2>
      <span className="expression-set-info-word-count">
        {word_count} word(s)
      </span>
      <p className="expression-set-info-description">{description}</p>
    </section>
  );
}
